/*
 * This Source Code Form is subject to the terms of the Mozilla Public License,
 * v. 2.0. If a copy of the MPL was not distributed with this file, You can
 * obtain one at https://mozilla.org/MPL/2.0/.
 *
 * Copyright 2025 Nicola Clark
 */

use std::{env, sync::LazyLock};

use env_logger::Logger;
use log::LevelFilter;
use macro_rules_attribute::apply;
use smol_macros::main;

static LOGGER: LazyLock<Logger> = LazyLock::new(|| {
  colog::default_builder()
    .filter_module("tide", LevelFilter::Warn)
    .build()
});

#[apply(main!)]
async fn main() {
  log::set_logger(&*LOGGER).unwrap();

  if let Ok(b_log_level) = env::var("B_LOG_LEVEL") {
    log::set_max_level(match b_log_level.as_str() {
      "off" => LevelFilter::Off,
      "error" => LevelFilter::Error,
      "warn" => LevelFilter::Warn,
      "debug" => LevelFilter::Debug,
      "trace" => LevelFilter::Trace,
      _ => LevelFilter::Info,
    });
  } else {
    log::set_max_level(LevelFilter::Info);
  }

  log::info!("spoon-blog v{}", env!("CARGO_PKG_VERSION"));

  let mut app = tide::new();
  app.at("/").get(async |_| Ok("howdy y'all!!!"));
  if let Err(tide_err) = app.listen("0.0.0.0:8080").await {
    log::error!("issue serving HTTP: {tide_err}");
  }
}
